/*
 * IcmpSystemException.java 
 *
 * Copyright (c) Verax Systems.
 * All rights reserved.
 *
 * This software is furnished under a license. Use, duplication,
 * disclosure and all other uses are restricted to the rights
 * specified in the written license agreement.
 */
package com.veraxsystems.icmp.jni.exception;

import com.veraxsystems.icmp.jni.IcmpJniBridge;
import com.veraxsystems.icmp.jni.exception.IcmpException;


/**
 * The exception generated during access to {@link IcmpJniBridge} DLL module. 
 * It stores low level error code (see WIN32 API) and message related to this code.
 */
public class IcmpSystemException extends IcmpException 
{
   
   private int errorCode;
   
   /**
    * The exception constructor. As the addition to <code>IcmpException</code>
    * the <code>erroCode</code> is handled. 
    * @param errorCodeVal low level error code
    * @param nativeErrorString error string describing error code
    */
   public IcmpSystemException(int errorCodeVal, String nativeErrorString) 
   {
      super(nativeErrorString);
      errorCode = errorCodeVal;
      return;
   } /* IcmpSystemError */
 

   /**
    * Get error code that caused this exception.
    * @return error code
    */
   public final int getErrorCode() 
   {
      return errorCode;
   }

   /**
    * Set system error code.
    * @param code error code
    */
   public final void setErrorCode(int code) 
   {
      errorCode = code;
   }
 
}
